package com.huiju.estateagents.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.entity.TaNews;
import com.huiju.estateagents.entity.TaPerson;
import com.huiju.estateagents.entity.TaShareActivity;
import com.huiju.estateagents.entity.TaShareChildRecord;
import com.huiju.estateagents.entity.TaShareRecord;
import com.huiju.estateagents.service.ITaPersonService;
import com.huiju.estateagents.service.ITaShareActivityService;
import com.huiju.estateagents.service.ITaShareChildRecordService;
import com.huiju.estateagents.service.ITaShareRecordService;
import io.swagger.models.auth.In;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
    * 拼团活动表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-10-17
 */
@RestController
@RequestMapping("/api")
public class TaShareActivityController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaShareActivityController.class);

    @Autowired
    public ITaShareActivityService iTaShareActivityService;
    
    @Autowired
    private ITaPersonService taPersonService;
    
    @Autowired
    private ITaShareRecordService taShareRecordService;
    
    @Autowired
    private ITaShareChildRecordService taShareChildRecordService;

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taShareActivity/list",method= RequestMethod.GET)
    public ResponseBean taShareActivityList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                            @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                            @RequestParam(value ="buildingId",required = false) String buildingId,
                                            @RequestParam(value ="activityName",required = false) String activityName,
                                            @RequestParam(value ="status",required = false) String status,
                                            HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean = iTaShareActivityService.getList(pageNum, pageSize, buildingId, activityName, status, null, null, getOrgId(request));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareActivityList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param parameter 实体对象json格式
     * @return
     */
    @RequestMapping(value="/admin/taShareActivity",method= RequestMethod.POST)
    public ResponseBean taShareActivityAdd(@RequestBody String parameter, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            TaShareActivity taShareActivity = JSONObject.parseObject(parameter, TaShareActivity.class);
            taShareActivity.setOrgId(getOrgId(request));
            taShareActivity.setStatus(0);
            taShareActivity.setActivityStatus(1);
            taShareActivity.setSort(false);
            taShareActivity.setWeight(0);
            if (iTaShareActivityService.save(taShareActivity)){
                responseBean.addSuccess(taShareActivity);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareActivityAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/admin/taShareActivity/{id}", method= RequestMethod.DELETE)
    public ResponseBean taShareActivityDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaShareActivityService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareActivityDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param  parameter 实体对象json
     * @return
     */
    @RequestMapping(value="/admin/taShareActivity/update",method= RequestMethod.PUT)
    public ResponseBean taShareActivityUpdate(@RequestBody String parameter){
        ResponseBean responseBean = new ResponseBean();
        try {
            TaShareActivity taShareActivity = JSONObject.parseObject(parameter, TaShareActivity.class);
            if (iTaShareActivityService.updateById(taShareActivity)){
                responseBean.addSuccess(taShareActivity);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareActivityUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taShareActivity/{id}",method= RequestMethod.GET)
    public ResponseBean taShareActivityGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaShareActivityService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareActivityDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id结束拼团活动
     * @param id
     * @return
     */
    @RequestMapping(value="/admin/taShareActivity/finish/{id}",method= RequestMethod.PUT)
    public ResponseBean finishShareActicity(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            TaShareActivity taShareActivity = new TaShareActivity();
            //活动禁用启用 0启动1禁用
            taShareActivity.setStatus(1);
            //0：进行中 1：未开始 2：已结束
            taShareActivity.setActivityStatus(2);
            taShareActivity.setGroupActicityId(id);
            if (iTaShareActivityService.updateById(taShareActivity)){
                responseBean.addSuccess(taShareActivity);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareActivityUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 置顶活动，首页推荐
     * @param taShareActivity
     * @param request
     * @return
     */
    @RequestMapping(value = "/admin/taShareActivity/weight" ,method =RequestMethod.PUT)
    public  ResponseBean buildingDynamicWeight(@RequestBody TaShareActivity taShareActivity, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        if (taShareActivity.getWeight() != null){
            taShareActivity.setWeight(taShareActivity.getWeight() == 0 ? 1 : 0);
        }
        if (taShareActivity.getSort() != null){
            taShareActivity.setSort(taShareActivity.getSort() == true ? false : true);
        }

        QueryWrapper<TaNews> newsQueryWrapper = new QueryWrapper<>();
        newsQueryWrapper.eq("group_acticity_id", taShareActivity.getGroupActicityId());
        if (iTaShareActivityService.updateById(taShareActivity)){
            responseBean.addSuccess("成功");
        }else {
            responseBean.addError("失败");
        }
        return responseBean;
    }
    
    /**
     * 微信端根据id查询详情
     * @param groupActicityId  实体ID
     */
    @RequestMapping(value="/wx/taShareActivity/{groupActicityId}",method= RequestMethod.GET)
    public ResponseBean wxShareActivityGet(@PathVariable Integer groupActicityId, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        String openid = getOpenId(request);
        Integer orgId = getOrgId(request);
        List<TaPerson> taPersons = taPersonService.getPersonsByOpenId(openid);
        if (null == taPersons || taPersons.size() != 1) {
            return ResponseBean.error("验证人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
        }
        TaPerson person = taPersons.get(0);
        Map<String,Object> map = new HashMap<>();
        try {
            //活动详情
            TaShareActivity taShareActivity = iTaShareActivityService.getById(groupActicityId);
            map.put("taShareActivity",taShareActivity);
            
            //发起者团长信息
            QueryWrapper<TaShareRecord> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("group_activity_id",groupActicityId);
            queryWrapper.eq("person_id",person.getPersonId());
            queryWrapper.eq("org_id",orgId);
            TaShareRecord taShareRecord = taShareRecordService.getOne(queryWrapper);
            if (null != taShareRecord){
                //团长
                taShareActivity.setGroupStatus(CommConstant.HELP_STATUS_INITIATE);
                map.put("taShareRecord",taShareRecord);
                
                //团员
                QueryWrapper<TaShareChildRecord> childRecordQueryWrapper = new QueryWrapper<>();
                childRecordQueryWrapper.eq("org_id",orgId);
                childRecordQueryWrapper.eq("group_activity_id",taShareActivity.getGroupActicityId());
                childRecordQueryWrapper.eq("record_id",taShareRecord.getRecordId());
                List<TaShareChildRecord> shareChildRecordList = taShareChildRecordService.list(childRecordQueryWrapper);
                map.put("shareChildRecordList",shareChildRecordList);
            }
            responseBean.addSuccess(map);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareActivityDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
    
}
